@@ -33,10 +33,6 @@
 #include <cstring>
 #include <stdexcept>
 
-#ifdef _WIN32
-#include "windows.h"
-#endif
-
 class ResourceException : public std::exception {
 protected:
     std::string resource;
@@ -50,8 +46,14 @@ public:
 class Resource {
     int refs;
 public:
-    std::string name;
-    Resource(std::string name) { this->name = name; refs=0; };
+    std::string resource_name;
+    Resource() { refs =0; };
+    Resource(const std::string& resource_name) : resource_name(resource_name), refs(0) {};
+
+    void setResourceName(const std::string& resource_name) {
+        if(this->resource_name.empty()) this->resource_name = resource_name;
+    };
+
     int refcount() { return refs; };
     void addref()  { refs++; };
     void deref()   { refs--; };
@@ -64,7 +66,7 @@ protected:
     std::string resource_dir;
 public:
 
-    void setDir(std::string resource_dir);
+    void setDir(const std::string& resource_dir);
     std::string getDir();
 
     ResourceManager();
@@ -73,8 +75,8 @@ public:
     void purge();
 
     void release(Resource* resource);
-    Resource* grab(std::string name);
-    virtual Resource* create(std::string name) { return 0; };
+    Resource* grab(const std::string& resource_name);
+    virtual Resource* create(const std::string& name) { return 0; };
 };
 
 #endif
