@@ -28,6 +28,16 @@
 #ifndef SDLAPP_H
 #define SDLAPP_H
 
+#ifdef _WIN32
+
+#ifdef _WIN32_WINNT
+#undef _WIN32_WINNT
+#endif
+
+#define _WIN32_WINNT 0x0501
+#include "windows.h"
+#endif
+
 #include "display.h"
 #include "logger.h"
 
@@ -42,6 +52,9 @@ extern std::string gSDLAppTitle;
 extern std::string gSDLAppExec;
 
 #ifdef _WIN32
+extern HWND gSDLAppConsoleWindow;
+
+bool SDLAppAttachToConsole();
 void SDLAppCreateWindowsConsole();
 void SDLAppResizeWindowsConsole(int height);
 #endif
@@ -63,10 +76,10 @@ public:
     SDLAppException(const char* str, ...) : showhelp(false) {
 
         va_list vl;
-        char msg[1024];
+        char msg[4096];
 
         va_start(vl, str);
-            vsnprintf(msg, 1024, str, vl);
+            vsnprintf(msg, 4096, str, vl);
         va_end(vl);
 
         message = std::string(msg);
@@ -87,9 +100,9 @@ class SDLApp {
     int fps_updater;
     int return_code;
 
-
     void updateFramerate();
 protected:
+    int  min_delta_msec;
     bool appFinished;
     void stop(int return_code);
 public:
@@ -100,16 +113,24 @@ public:
 
     int run();
 
+    virtual void resize(int width, int height) {};
+
     virtual void update(float t, float dt) {};
     virtual void init() {};
 
     virtual void logic(float t, float dt) {};
     virtual void draw(float t, float dt) {};
 
+    virtual void quit() { appFinished = true; };
+    
     virtual void mouseMove(SDL_MouseMotionEvent *e) {};
     virtual void mouseClick(SDL_MouseButtonEvent *e) {};
     virtual void keyPress(SDL_KeyboardEvent *e) {};
 
+#if SDL_VERSION_ATLEAST(1,3,0)
+    virtual void mouseWheel(SDL_MouseWheelEvent *e) {};
+#endif
+
     int returnCode();
     bool isFinished();
 };
