@@ -32,7 +32,7 @@ Gource::Gource(FrameExporter* exporter) {
     if(!GLEW_VERSION_2_0) gGourceSettings.ffp = true;
 
     if(!gGourceSettings.file_graphic) {
-        gGourceSettings.file_graphic = texturemanager.grab("file.png");
+        gGourceSettings.file_graphic = texturemanager.grab("file.png", true, GL_CLAMP_TO_EDGE);
     }
 
     fontlarge = fontmanager.grab("FreeSans.ttf", 42);
@@ -52,7 +52,7 @@ Gource::Gource(FrameExporter* exporter) {
 
     bloomtex = texturemanager.grab(bloom_tga);
     beamtex  = texturemanager.grab("beam.png");
-    usertex  = texturemanager.grab("no_photo.png");
+    usertex  = texturemanager.grab("user.png", true, GL_CLAMP_TO_EDGE);
 
     shadow_shader = text_shader = bloom_shader = 0;
 
@@ -84,16 +84,12 @@ Gource::Gource(FrameExporter* exporter) {
 
     paused       = false;
     first_read   = true;
-    draw_loading = true;
 
     grab_mouse   = false;
     mousemoved   = false;
     mousedragged = false;
     mouseclicked = false;
 
-    cursor.setCursorTexture(texturemanager.grab("cursor.png"));
-    cursor.useSystemCursor(false);
-
     if(gGourceSettings.hide_mouse) {
         cursor.showCursor(false);
     }
@@ -121,7 +117,7 @@ Gource::Gource(FrameExporter* exporter) {
 
     file_key = FileKey(1.0f);
 
-    camera = ZoomCamera(vec3f(0,0, -300), vec3f(0.0, 0.0, 0.0), 250.0, 5000.0);
+    camera = ZoomCamera(vec3(0,0, -300), vec3(0.0, 0.0, 0.0), gGourceSettings.camera_zoom_default, gGourceSettings.camera_zoom_max);
     camera.setPadding(gGourceSettings.padding);
 
     setCameraMode(gGourceSettings.camera_mode);
@@ -136,6 +132,10 @@ Gource::Gource(FrameExporter* exporter) {
 
     reset();
 
+    logmill = new RLogMill(logfile);
+
+    shutdown = false;
+    
     if(exporter!=0) setFrameExporter(exporter, gGourceSettings.output_framerate);
 
     //if recording a video or in demo mode, or multiple repos, the slider is initially hidden
@@ -143,9 +143,17 @@ Gource::Gource(FrameExporter* exporter) {
 }
 
 void Gource::writeCustomLog(const std::string& logfile, const std::string& output_file) {
-    RCommitLog* commitlog = determineFormat(logfile);
 
-    if(!commitlog) return;
+    RLogMill logmill(logfile);
+    RCommitLog* commitlog = logmill.getLog();
+
+    // TODO: exception handling
+
+    if(!commitlog) {
+        std::string error = logmill.getError();
+        if(!error.empty()) SDLAppQuit(error);
+        return;
+    }
 
     RCommit commit;
 
@@ -179,140 +187,11 @@ void Gource::writeCustomLog(const std::string& logfile, const std::string& outpu
     if(output_file != "-") fclose(fh);
 }
 
-RCommitLog* Gource::determineFormat(const std::string& logfile) {
-    debugLog("determineFormat(%s)\n", logfile.c_str());
-
-    RCommitLog* clog = 0;
-
-    //we've been told what format to use
-    if(gGourceSettings.log_format.size() > 0) {
-        debugLog("--log-format = %s\n", gGourceSettings.log_format.c_str());
-
-        if(gGourceSettings.log_format == "git") {
-            clog = new GitCommitLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-
-            clog = new GitRawCommitLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "hg") {
-            clog = new MercurialLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-        if(gGourceSettings.log_format == "bzr") {
-            clog = new BazaarLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "cvs") {
-            clog = new CVSEXPCommitLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "custom") {
-            clog = new CustomLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "apache") {
-            clog = new ApacheCombinedLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "svn") {
-            clog = new SVNCommitLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        if(gGourceSettings.log_format == "cvs2cl") {
-            clog = new CVS2CLCommitLog(logfile);
-            if(clog->checkFormat()) return clog;
-            delete clog;
-        }
-
-        return 0;
-    }
-
-    //git
-    debugLog("trying git...\n");
-    clog = new GitCommitLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //mercurial
-    debugLog("trying mercurial...\n");
-    clog = new MercurialLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //bzr
-    debugLog("trying bzr...\n");
-    clog = new BazaarLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //git raw
-    debugLog("trying git raw...\n");
-    clog = new GitRawCommitLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //cvs exp
-    debugLog("trying cvs-exp...\n");
-    clog = new CVSEXPCommitLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //svn
-    debugLog("trying svn...\n");
-    clog = new SVNCommitLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //cvs2cl
-    debugLog("trying cvs2cl...\n");
-    clog = new CVS2CLCommitLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //custom
-    debugLog("trying custom...\n");
-    clog = new CustomLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    //apache
-    debugLog("trying apache combined...\n");
-    clog = new ApacheCombinedLog(logfile);
-    if(clog->checkFormat()) return clog;
-
-    delete clog;
-
-    return 0;
-}
-
 Gource::~Gource() {
     reset();
 
-    if(commitlog!=0) delete commitlog;
-    if(root!=0) delete root;
+    if(logmill!=0)   delete logmill;
+    if(root!=0)      delete root;
 
     //reset settings
     gGourceSettings.setGourceDefaults();
@@ -321,6 +200,25 @@ Gource::~Gource() {
 void Gource::init() {
 }
 
+void Gource::unload() {
+
+    file_vbo.unload();
+    user_vbo.unload();
+    edge_vbo.unload();
+    action_vbo.unload();
+    bloom_vbo.unload();
+
+}
+
+void Gource::reload() {
+
+    slider.resize();
+}
+
+void Gource::quit() {
+    shutdown = true;    
+}
+
 void Gource::update(float t, float dt) {
 
     float scaled_dt = std::min(dt, max_tick_rate);
@@ -347,7 +245,7 @@ void Gource::update(float t, float dt) {
     draw(runtime, scaled_dt);
 
     //extract frames based on frameskip setting if frameExporter defined
-    if(frameExporter != 0) {
+    if(frameExporter != 0 && commitlog && !shutdown) {
         if(framecount % (frameskip+1) == 0) {
             frameExporter->dump();
         }
@@ -388,6 +286,7 @@ void Gource::mouseMove(SDL_MouseMotionEvent *e) {
 
     bool rightmouse = cursor.rightButtonPressed();
 
+#if not SDL_VERSION_ATLEAST(1,3,0)
     if(grab_mouse) {
          int warp_x = display.width/2;
          int warp_y = display.height/2;
@@ -397,10 +296,11 @@ void Gource::mouseMove(SDL_MouseMotionEvent *e) {
 
          SDL_WarpMouse(warp_x, warp_y);
     }
+#endif
 
     //move camera in direction the user dragged the mouse
     if(mousedragged || rightmouse) {
-        vec2f mag( e->xrel, e->yrel );
+        vec2 mag( e->xrel, e->yrel );
 
         //if right mouse button is held while dragging, rotate tree instead of
         //moving camera
@@ -425,7 +325,7 @@ void Gource::mouseMove(SDL_MouseMotionEvent *e) {
 
     if(grab_mouse) return;
 
-    mousepos = vec2f(e->x, e->y);
+    mousepos = vec2(e->x, e->y);
     mousemoved=true;
 
     cursor.updatePos(mousepos);
@@ -450,16 +350,35 @@ void Gource::zoom(bool zoomin) {
     if(zoomin) {
         distance /= zoom_multi;
 
-        if(distance < 100.0f) distance = 100.0f;
+        if(distance < gGourceSettings.camera_zoom_min) distance = gGourceSettings.camera_zoom_min;
     } else {
         distance *= zoom_multi;
 
-        if(distance > 4999.0f) distance = 4999.0f;
+        if(distance > gGourceSettings.camera_zoom_max) distance = gGourceSettings.camera_zoom_max;
     }
 
     camera.setDistance(distance);
 }
 
+#if SDL_VERSION_ATLEAST(1,3,0)
+void Gource::mouseWheel(SDL_MouseWheelEvent *e) {
+
+   int mouse_x, mouse_y;
+    SDL_GetMouseState(&mouse_x, &mouse_y);
+
+    vec2 mousepos(mouse_x, mouse_y);
+
+    if(e->y > 0) {
+        zoom(true);
+    }
+
+    if(e->y < 0) {
+        zoom(false);
+    }
+}
+
+#endif
+
 void Gource::mouseClick(SDL_MouseButtonEvent *e) {
     if(commitlog==0) return;
     if(gGourceSettings.hide_mouse) return;
@@ -477,9 +396,14 @@ void Gource::mouseClick(SDL_MouseButtonEvent *e) {
 
         if(e->button == SDL_BUTTON_LEFT || e->button == SDL_BUTTON_RIGHT) {
             if(!cursor.buttonPressed()) {
-                cursor.showCursor(true);
                 grab_mouse=false;
-                SDL_WarpMouse(mousepos.x, mousepos.y);
+#if SDL_VERSION_ATLEAST(1,3,0)
+		SDL_SetRelativeMouseMode(SDL_FALSE);
+		SDL_WarpMouseInWindow(display.sdl_window, mousepos.x, mousepos.y);
+#else
+		SDL_WarpMouse(mousepos.x, mousepos.y);
+#endif
+                cursor.showCursor(true);
             }
         }
     }
@@ -507,12 +431,15 @@ void Gource::mouseClick(SDL_MouseButtonEvent *e) {
     if(e->button == SDL_BUTTON_RIGHT) {
         cursor.showCursor(false);
         grab_mouse=true;
+#if SDL_VERSION_ATLEAST(1,3,0)
+        SDL_SetRelativeMouseMode(SDL_TRUE);
+#endif
         return;
     }
 
     if(e->button == SDL_BUTTON_LEFT) {
 
-        //mousepos = vec2f(e->x, e->y);
+        //mousepos = vec2(e->x, e->y);
         mouseclicked=true;
 
         if(canSeek()) {
@@ -682,8 +609,35 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
     if (e->type == SDL_KEYUP) return;
 
     if (e->type == SDL_KEYDOWN) {
-        if (e->keysym.unicode == SDLK_ESCAPE) {
-            appFinished=true;
+
+#if SDL_VERSION_ATLEAST(1,3,0)
+        bool key_escape       = e->keysym.scancode == SDL_SCANCODE_ESCAPE;
+        bool key_tab          = e->keysym.scancode == SDL_SCANCODE_TAB;
+        bool key_space        = e->keysym.scancode == SDL_SCANCODE_SPACE;
+        bool key_plus         = e->keysym.scancode == SDL_SCANCODE_EQUALS;
+        bool key_equals       = e->keysym.scancode == SDL_SCANCODE_EQUALS;
+        bool key_minus        = e->keysym.scancode == SDL_SCANCODE_MINUS;
+        bool key_leftbracket  = e->keysym.scancode == SDL_SCANCODE_LEFTBRACKET;
+        bool key_rightbracket = e->keysym.scancode == SDL_SCANCODE_RIGHTBRACKET;
+        bool key_comma        = e->keysym.scancode == SDL_SCANCODE_COMMA;
+        bool key_period       = e->keysym.scancode == SDL_SCANCODE_PERIOD;
+        bool key_slash        = e->keysym.scancode == SDL_SCANCODE_SLASH;
+#else
+        bool key_escape       = e->keysym.unicode == SDLK_ESCAPE;
+        bool key_tab          = e->keysym.unicode == SDLK_TAB;
+        bool key_space        = e->keysym.unicode == SDLK_SPACE;
+        bool key_plus         = e->keysym.unicode == SDLK_PLUS;
+        bool key_equals       = e->keysym.unicode == SDLK_EQUALS;
+        bool key_minus        = e->keysym.unicode == SDLK_MINUS;
+        bool key_leftbracket  = e->keysym.unicode == SDLK_LEFTBRACKET;
+        bool key_rightbracket = e->keysym.unicode == SDLK_RIGHTBRACKET;
+        bool key_comma        = e->keysym.unicode == SDLK_COMMA;
+        bool key_period       = e->keysym.unicode == SDLK_PERIOD;
+        bool key_slash        = e->keysym.unicode == SDLK_SLASH;
+#endif
+
+        if (key_escape) {
+            quit();
         }
 
         if(commitlog==0) return;
@@ -809,15 +763,15 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
             recolour=true;
         }
 
-        if(e->keysym.unicode == SDLK_TAB) {
+        if(key_tab) {
             selectNextUser();
         }
 
-        if (e->keysym.unicode == SDLK_SPACE) {
+        if (key_space) {
             paused = !paused;
         }
 
-        if (e->keysym.unicode == SDLK_EQUALS || e->keysym.unicode == SDLK_PLUS) {
+        if (key_equals || key_plus) {
             if(gGourceSettings.days_per_second>=1.0) {
                 gGourceSettings.days_per_second = std::min(30.0f, floorf(gGourceSettings.days_per_second) + 1.0f);
             } else {
@@ -825,7 +779,7 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
             }
         }
 
-        if (e->keysym.unicode == SDLK_MINUS) {
+        if (key_minus) {
             if(gGourceSettings.days_per_second>1.0) {
                 gGourceSettings.days_per_second = std::max(0.0f, floorf(gGourceSettings.days_per_second) - 1.0f);
             } else {
@@ -841,15 +795,15 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
             zoom(false);
         }
 
-        if(e->keysym.unicode == SDLK_LEFTBRACKET) {
+        if(key_leftbracket) {
             gGourceForceGravity /= 1.1;
         }
 
-        if(e->keysym.unicode == SDLK_RIGHTBRACKET) {
+        if(key_rightbracket) {
             gGourceForceGravity *= 1.1;
         }
 
-        if(e->keysym.unicode == SDLK_PERIOD) {
+        if(key_period) {
 
             if(gGourceSettings.time_scale>=1.0) {
                 gGourceSettings.time_scale = std::min(4.0f, floorf(gGourceSettings.time_scale) + 1.0f);
@@ -858,7 +812,7 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
             }
         }
 
-        if(e->keysym.unicode == SDLK_COMMA) {
+        if(key_comma) {
 
             if(gGourceSettings.time_scale>1.0) {
                 gGourceSettings.time_scale = std::max(0.0f, floorf(gGourceSettings.time_scale) - 1.0f);
@@ -867,7 +821,7 @@ void Gource::keyPress(SDL_KeyboardEvent *e) {
             }
         }
 
-        if(e->keysym.unicode == SDLK_SLASH) {
+        if(key_slash) {
             gGourceSettings.time_scale = 1.0f;
         }
     }
@@ -904,7 +858,7 @@ void Gource::reset() {
 
     message_timer = 0.0f;
 
-    cursor_move = vec2f(0.0f, 0.0f);
+    cursor_move = vec2(0.0f, 0.0f);
 
     selectedUser = 0;
     hoverUser = 0;
@@ -917,6 +871,8 @@ void Gource::reset() {
     mousemoved=false;
     mousedragged = false;
 
+    commitqueue_max_size = 100;
+
     rotate_angle = 0.0f;
 
     if(root!=0) delete root;
@@ -980,9 +936,19 @@ void Gource::deleteFile(RFile* file) {
 
 RFile* Gource::addFile(const RCommitFile& cf) {
 
+    //if we already have max files in circulation
+    //we cant add any more
+    if(gGourceSettings.max_files > 0 && files.size() >= gGourceSettings.max_files) return 0;
+
+    //see if this is a directory
+    std::string file_as_dir = cf.filename;
+    if(file_as_dir[file_as_dir.size()-1] != '/') file_as_dir.append("/");
+
+    if(root->isDir(file_as_dir)) return 0;
+
     int tagid = tag_seq++;
 
-    RFile* file = new RFile(cf.filename, cf.colour, vec2f(0.0,0.0), tagid);
+    RFile* file = new RFile(cf.filename, cf.colour, vec2(0.0,0.0), tagid);
 
     files[cf.filename] = file;
     tagfilemap[tagid]  = file;
@@ -992,7 +958,7 @@ RFile* Gource::addFile(const RCommitFile& cf) {
     file_key.inc(file);
 
     while(root->getParent() != 0) {
-        debugLog("parent changed to %s\n", root->getPath().c_str());
+        debugLog("parent changed to %s", root->getPath().c_str());
         root = root->getParent();
     }
 
@@ -1001,12 +967,12 @@ RFile* Gource::addFile(const RCommitFile& cf) {
 
 RUser* Gource::addUser(const std::string& username) {
 
-    vec2f pos;
+    vec2 pos;
 
     if(dir_bounds.area() > 0) {
         pos = dir_bounds.centre();
     } else {
-        pos = vec2f(0,0);
+        pos = vec2(0,0);
     }
 
     int tagid = tag_seq++;
@@ -1063,7 +1029,8 @@ void Gource::readLog() {
 
     //debugLog("readLog()\n");
 
-    while(!commitlog->isFinished() && commitqueue.size() < 1) {
+    // read commits until either we are ahead of currtime
+    while(!commitlog->isFinished() && (commitqueue.empty() || commitqueue.back().timestamp <= currtime && commitqueue.size() < commitqueue_max_size)) {
 
         RCommit commit;
 
@@ -1074,13 +1041,11 @@ void Gource::readLog() {
             continue;
         }
 
-        //ignore blank commits
-        if(commit.files.size() > 0) {
-            commitqueue.push_back(commit);
-        }
+         commitqueue.push_back(commit);
     }
 
-    if(first_read && commitqueue.size()==0) {
+    if(first_read && commitqueue.empty()) {
+        fprintf(stderr, "no files on first read\n");
         throw SDLAppException("no commits found");
     }
 
@@ -1104,40 +1069,12 @@ void Gource::readLog() {
 
 void Gource::processCommit(RCommit& commit, float t) {
 
-    //check user against filters, if found, discard commit
-    if(!gGourceSettings.user_filters.empty()) {
-        for(std::vector<Regex*>::iterator ri = gGourceSettings.user_filters.begin(); ri != gGourceSettings.user_filters.end(); ri++) {
-            Regex* r = *ri;
-
-            if(r->match(commit.username)) {
-                return;
-            }
-        }
-    }
-
     //find files of this commit or create it
     for(std::list<RCommitFile>::iterator it = commit.files.begin(); it != commit.files.end(); it++) {
 
         RCommitFile& cf = *it;
         RFile* file = 0;
 
-        //check filename against filters
-        if(!gGourceSettings.file_filters.empty()) {
-
-            bool filtered_filename = false;
-
-            for(std::vector<Regex*>::iterator ri = gGourceSettings.file_filters.begin(); ri != gGourceSettings.file_filters.end(); ri++) {
-                Regex* r = *ri;
-
-                if(r->match(cf.filename)) {
-                    filtered_filename = true;
-                    break;
-                }
-            }
-
-            if(filtered_filename) continue;
-        }
-
         //is this a directory (ends in slash)
         //deleting a directory - find directory: then for each file, remove each file
 
@@ -1155,7 +1092,7 @@ void Gource::processCommit(RCommit& commit, float t) {
             for(std::list<RDirNode*>::iterator it = dirs.begin(); it != dirs.end(); it++) {
 
                 RDirNode* dir = (*it);
-                
+
                 //fprintf(stderr, "deleting everything under %s because of %s\n", dir->getPath().c_str(), cf.filename.c_str());
 
                 //foreach dir files
@@ -1169,7 +1106,7 @@ void Gource::processCommit(RCommit& commit, float t) {
                     addFileAction(commit.username, cf.action, file, t);
                 }
             }
-                
+
             return;
         }
 
@@ -1178,12 +1115,9 @@ void Gource::processCommit(RCommit& commit, float t) {
 
         if(file == 0) {
 
-            //if we already have max files in circulation
-            //we cant add any more
-            if(gGourceSettings.max_files > 0 && files.size() >= gGourceSettings.max_files)
-                continue;
-
             file = addFile(cf);
+
+            if(!file) continue;
         }
 
         addFileAction(commit.username, cf.action, file, t);
@@ -1204,13 +1138,17 @@ void Gource::addFileAction(const std::string& username, const std::string& actio
     if(user == 0) {
         user = addUser(username);
 
-        // set the highlighted flag if name matches a highlighted user
-        for(std::vector<std::string>::iterator hi = gGourceSettings.highlight_users.begin(); hi != gGourceSettings.highlight_users.end(); hi++) {
-            std::string highlight = *hi;
+        if(gGourceSettings.highlight_all_users) user->setHighlighted(true);
+        else {
+        
+            // set the highlighted flag if name matches a highlighted user
+            for(std::vector<std::string>::iterator hi = gGourceSettings.highlight_users.begin(); hi != gGourceSettings.highlight_users.end(); hi++) {
+                std::string highlight = *hi;
 
-            if(highlight.size() && user->getName() == highlight) {
-                user->setHighlighted(true);
-                break;
+                if(!highlight.empty() && user->getName() == highlight) {
+                    user->setHighlighted(true);
+                    break;
+                }
             }
         }
     }
@@ -1240,8 +1178,8 @@ void Gource::interactUsers() {
     // update quad tree
     Bounds2D quadtreebounds = user_bounds;
 
-    quadtreebounds.min -= vec2f(1.0f, 1.0f);
-    quadtreebounds.max += vec2f(1.0f, 1.0f);
+    quadtreebounds.min -= vec2(1.0f, 1.0f);
+    quadtreebounds.max += vec2(1.0f, 1.0f);
 
     update_user_tree_time = SDL_GetTicks();
 
@@ -1365,8 +1303,8 @@ void Gource::interactDirs() {
     // update quad tree
     Bounds2D quadtreebounds = dir_bounds;
 
-    quadtreebounds.min -= vec2f(1.0f, 1.0f);
-    quadtreebounds.max += vec2f(1.0f, 1.0f);
+    quadtreebounds.min -= vec2(1.0f, 1.0f);
+    quadtreebounds.max += vec2(1.0f, 1.0f);
 
     update_dir_tree_time = SDL_GetTicks();
 
@@ -1427,13 +1365,13 @@ void Gource::updateCamera(float dt) {
 
     if(manual_camera) {
 
-        if(cursor_move.length2() > 0.0f) {
+        if(glm::length2(cursor_move) > 0.0f) {
 
             float cam_rate = ( -camera.getPos().z ) / ( 5000.0f );
 
-            vec3f cam_pos = camera.getPos();
+            vec3 cam_pos = camera.getPos();
 
-            vec2f cursor_delta = cursor_move * cam_rate * 400.0f * dt;
+            vec2 cursor_delta = cursor_move * cam_rate * 400.0f * dt;
 
             cam_pos.x += cursor_delta.x;
             cam_pos.y += cursor_delta.y;
@@ -1443,7 +1381,7 @@ void Gource::updateCamera(float dt) {
 
             auto_rotate = false;
 
-            cursor_move = vec2f(0.0f, 0.0f);
+            cursor_move = vec2(0.0f, 0.0f);
         }
 
     } else {
@@ -1453,7 +1391,7 @@ void Gource::updateCamera(float dt) {
         if(track_users && (selectedFile !=0 || selectedUser !=0)) {
             Bounds2D focusbounds;
 
-            vec3f camerapos = camera.getPos();
+            vec3 camerapos = camera.getPos();
 
             if(selectedUser !=0) focusbounds.update(selectedUser->getPos());
             if(selectedFile !=0) focusbounds.update(selectedFile->getAbsolutePos());
@@ -1484,9 +1422,11 @@ void Gource::updateCamera(float dt) {
 
         } else if(!cursor.rightButtonPressed() && dir_bounds.area() > 10000.0f) {
 
-            float ratio = dir_bounds.width() / dir_bounds.height();
+            float aspect_ratio = display.width / (float) display.height;
 
-            if(ratio < 0.67f) {
+            float bounds_ratio = (aspect_ratio > 1.0f) ? dir_bounds.width() / dir_bounds.height() : dir_bounds.height() / dir_bounds.width();
+
+            if(bounds_ratio < 0.67f) {
                 rotation_remaining_angle = 90.0f;
             }
         }
@@ -1513,34 +1453,37 @@ void Gource::changeColours() {
 
 void Gource::logic(float t, float dt) {
 
-    if(draw_loading) return;
-
+    if(shutdown && logmill->isFinished()) {
+        appFinished=true;
+        return;
+    }
+    
     if(message_timer>0.0f) message_timer -= dt;
     if(splash>0.0f)        splash -= dt;
 
     //init log file
     if(commitlog == 0) {
 
-        try {
+        if(!logmill->isFinished()) return;
+        
+        commitlog = logmill->getLog();
 
-            commitlog = determineFormat(logfile);
+        std::string error = logmill->getError();
 
-        } catch(SeekLogException& exception) {
-            throw SDLAppException("unable to read log file");
-        }
+        if(!commitlog) {
+
+            if(!error.empty()) {
+                throw SDLAppException(error);
+            } else {
+
+                if(frameExporter!=0) frameExporter->stop();
 
-        if(commitlog == 0) {
-            //if not in a git dir and no log file, show help
-            if(logfile.size() == 0 || logfile == ".") {
                 SDL_Quit();
 
                 SDLAppException exception("");
                 exception.setShowHelp(true);
+
                 throw exception;
-            } else if(SDLAppDirExists(logfile)) {
-                throw SDLAppException("directory not supported");
-            } else {
-                throw SDLAppException("unsupported log format (you may need to regenerate your log file)");
             }
         }
 
@@ -1553,24 +1496,43 @@ void Gource::logic(float t, float dt) {
 
     slider.logic(dt);
 
+    bool right = false;
+    bool left  = false;
+    bool up    = false;
+    bool down  = false;
+
+#if SDL_VERSION_ATLEAST(1,3,0)
+    Uint8 *keystate = SDL_GetKeyboardState(0);
+
+    right = keystate[SDL_SCANCODE_RIGHT];
+    left  = keystate[SDL_SCANCODE_LEFT];
+    up    = keystate[SDL_SCANCODE_UP];
+    down  = keystate[SDL_SCANCODE_DOWN];
+#else
     Uint8 *keystate = SDL_GetKeyState(0);
 
-    if(keystate[SDLK_RIGHT]) {
+    right = keystate[SDLK_RIGHT];
+    left  = keystate[SDLK_LEFT];
+    up    = keystate[SDLK_UP];
+    down  = keystate[SDLK_DOWN];
+#endif
+
+    if(right) {
         cursor_move.x = 10.0;
         manual_camera = true;
     }
 
-    if(keystate[SDLK_LEFT]) {
+    if(left) {
         cursor_move.x = -10.0;
         manual_camera = true;
     }
 
-    if(keystate[SDLK_UP]) {
+    if(up) {
         cursor_move.y = -10.0;
         manual_camera = true;
     }
 
-    if(keystate[SDLK_DOWN]) {
+    if(down) {
         cursor_move.y = 10.0;
         manual_camera = true;
     }
@@ -1586,9 +1548,9 @@ void Gource::logic(float t, float dt) {
         for(std::map<std::string,RUser*>::iterator it = users.begin(); it!=users.end(); it++) {
             RUser* user = it->second;
 
-            vec2f userpos = user->getPos();
+            vec2 userpos = user->getPos();
 
-            user->setPos(userpos.rotate(s, c));
+            user->setPos(rotate_vec2(userpos, s, c));
         }
 
         rotate_angle = 0.0f;
@@ -1616,18 +1578,18 @@ void Gource::logic(float t, float dt) {
     }
 
     // get more entries
-    if(commitqueue.size() == 0) {
+    if(commitqueue.empty()) {
         readLog();
     }
 
     //loop in attempt to find commits
-    if(commitqueue.size()==0 && commitlog->isSeekable() && gGourceSettings.loop) {
+    if(commitqueue.empty() && commitlog->isSeekable() && gGourceSettings.loop) {
         first_read=true;
         seekTo(0.0);
         readLog();
     }
 
-    if(currtime==0 && commitqueue.size()) {
+    if(currtime==0 && !commitqueue.empty()) {
         currtime   = lasttime = commitqueue[0].timestamp;
         subseconds = 0.0;
     }
@@ -1654,9 +1616,9 @@ void Gource::logic(float t, float dt) {
 
 
     //add commits up until the current time
-    while(commitqueue.size() > 0) {
+    while(!commitqueue.empty()) {
 
-        RCommit commit = commitqueue[0];
+        RCommit commit = commitqueue.front();
 
         //auto skip ahead, unless stop_position_reached
         if(gGourceSettings.auto_skip_seconds>=0.0 && idle_time >= gGourceSettings.auto_skip_seconds && !stop_position_reached) {
@@ -1689,14 +1651,14 @@ void Gource::logic(float t, float dt) {
 
     updateCamera(dt);
 
-    updateTime(commitqueue.size() > 0 ? currtime : lasttime);
+    updateTime(!commitqueue.empty() ? currtime : lasttime);
 }
 
 void Gource::mousetrace(float dt) {
 
-    vec3f cam_pos = camera.getPos();
+    vec3 cam_pos = camera.getPos();
 
-    vec2f projected_mouse = vec2f( -(mousepos.x * 2.0f - ((float)display.width)) / ((float)display.height),
+    vec2 projected_mouse = vec2( -(mousepos.x * 2.0f - ((float)display.width)) / ((float)display.height),
                                    (1.0f - (2.0f * mousepos.y) / ((float)display.height)))
                                    * cam_pos.z;
     projected_mouse.x += cam_pos.x;
@@ -1813,16 +1775,34 @@ void Gource::loadingScreen() {
 
     glColor4f(1.0, 1.0, 1.0, 1.0);
 
-    std::string loading_message("Reading Log...");
-    int width = font.getWidth(loading_message);
+    const char* progress;
 
-    font.print(display.width/2 - width/2, display.height/2 - 10, "%s", loading_message.c_str());
+    switch(int(runtime*3.0f)%4) {
+        case 0:
+            progress = "";
+            break;
+        case 1:
+            progress = ".";
+            break;
+        case 2:
+            progress = "..";
+            break;
+        case 3:
+            progress = "...";
+            break;
+    }
+
+    const char* action = !shutdown ? "Reading Log" : "Aborting";
+    
+    int width = font.getWidth(action);
+    font.setColour(vec4(1.0f));
+    font.print(display.width/2 - width/2, display.height/2 - 10, "%s%s", action, progress);
 }
 
 void Gource::drawBackground(float dt) {
     if(!gGourceDrawBackground) return;
 
-    display.setClearColour(vec4f(gGourceSettings.background_colour, gGourceSettings.transparent ? 0.0f : 1.0f));
+    display.setClearColour(vec4(gGourceSettings.background_colour, gGourceSettings.transparent ? 0.0f : 1.0f));
     display.clear();
 
     if(backgroundtex!=0) {
@@ -1866,12 +1846,10 @@ void Gource::drawScene(float dt) {
 
     draw_edges_time = SDL_GetTicks() - draw_edges_time;
 
-    //draw shadows
+    //draw file shadows
 
     draw_shadows_time = SDL_GetTicks();
 
-    drawUserShadows(dt);
-
     drawFileShadows(dt);
 
     draw_shadows_time = SDL_GetTicks() - draw_shadows_time;
@@ -1896,6 +1874,8 @@ void Gource::drawScene(float dt) {
 
     draw_users_time = SDL_GetTicks();
 
+    drawUserShadows(dt);
+
     drawUsers(dt);
 
     draw_users_time = SDL_GetTicks() - draw_users_time;
@@ -1942,7 +1922,7 @@ void Gource::updateAndDrawEdges() {
         shadow_shader->use();
         shadow_shader->setFloat("shadow_strength", 0.5);
 
-        vec2f shadow_offset = vec2f(2.0, 2.0);
+        vec2 shadow_offset = vec2(2.0, 2.0);
 
         glPushMatrix();
             glTranslatef(shadow_offset.x, shadow_offset.y, 0.0f);
@@ -2085,9 +2065,9 @@ void Gource::updateVBOs(float dt) {
             RUser* user = it->second;
 
             float alpha = user->getAlpha();
-            vec3f col   = user->getColour();
+            vec3 col   = user->getColour();
 
-            user_vbo.add(user->graphic->textureid, user->getPos() - user->dims*0.5f, user->dims, vec4f(col.x, col.y, col.z, alpha));
+            user_vbo.add(user->graphic->textureid, user->getPos() - user->dims*0.5f, user->dims, vec4(col.x, col.y, col.z, alpha));
 
             //draw actions
             user->updateActionsVBO(action_vbo);
@@ -2147,7 +2127,7 @@ void Gource::drawUserShadows(float dt) {
         shadow_shader->use();
         shadow_shader->setFloat("shadow_strength", 0.5);
 
-        vec2f shadow_offset = vec2f(2.0, 2.0) * gGourceSettings.user_scale;
+        vec2 shadow_offset = vec2(2.0, 2.0) * gGourceSettings.user_scale;
 
         glPushMatrix();
             glTranslatef(shadow_offset.x, shadow_offset.y, 0.0f);
@@ -2217,13 +2197,12 @@ void Gource::draw(float t, float dt) {
 
     drawBackground(dt);
 
-    if(draw_loading) {
+    if(!commitlog) {
         loadingScreen();
-        draw_loading = false;
         return;
     }
 
-    Frustum frustum(camera);
+    Frustum frustum(camera.getPos(), camera.getTarget(), camera.getUp(), camera.getFOV(), camera.getZNear(), camera.getZFar());
 
     trace_time = SDL_GetTicks();
 
@@ -2305,7 +2284,8 @@ void Gource::draw(float t, float dt) {
         fontmanager.startBuffer();
     }
 
-    font.roundCoordinates(false);
+    font.roundCoordinates(false);    
+    font.setColour(vec4(gGourceSettings.dir_colour, 1.0f));
 
     root->drawNames(font);
 
@@ -2390,7 +2370,7 @@ void Gource::draw(float t, float dt) {
     glEnable(GL_BLEND);
     glEnable(GL_TEXTURE_2D);
 
-    vec3f campos = camera.getPos();
+    vec3 campos = camera.getPos();
 
     if(logotex!=0) {
         glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -2401,7 +2381,7 @@ void Gource::draw(float t, float dt) {
 
         glBindTexture(GL_TEXTURE_2D, logotex->textureid);
 
-        vec2f logopos = vec2f(display.width, display.height) - vec2f(logotex->w, logotex->h) - gGourceSettings.logo_offset;
+        vec2 logopos = vec2(display.width, display.height) - vec2(logotex->w, logotex->h) - gGourceSettings.logo_offset;
 
         glPushMatrix();
 
@@ -2432,7 +2412,7 @@ void Gource::draw(float t, float dt) {
         int cwidth    = font.getWidth("Software Version Control Visualization");
         int awidth    = font.getWidth("(C) 2009 Andrew Caudwell");
 
-        vec2f corner(display.width/2 - logowidth/2 - 30.0f, display.height/2 - 40);
+        vec2 corner(display.width/2 - logowidth/2 - 30.0f, display.height/2 - 40);
 
         glDisable(GL_TEXTURE_2D);
         glColor4f(0.0f, 0.5f, 1.0f, splash * 0.015f);
@@ -2445,16 +2425,18 @@ void Gource::draw(float t, float dt) {
 
         glEnable(GL_TEXTURE_2D);
 
-        glColor4f(1.0,1.0,1.0,1.0);
+        fontlarge.setColour(vec4(1.0f));
         fontlarge.draw(display.width/2 - logowidth/2,display.height/2 - 30, "Gource");
+
+        font.setColour(vec4(1.0f));
         font.draw(display.width/2 - cwidth/2,display.height/2 + 10, "Software Version Control Visualization");
         font.draw(display.width/2 - awidth/2,display.height/2 + 30, "(C) 2009 Andrew Caudwell");
     }
 
     // text using the specified font goes here
 
-    fontmedium.setColour(vec4f(gGourceSettings.font_colour, 1.0f));
-    
+    fontmedium.setColour(vec4(gGourceSettings.font_colour, 1.0f));
+
     if(!gGourceSettings.hide_date) {
         fontmedium.draw(display.width/2 - date_x_offset, 20, displaydate);
     }
@@ -2502,17 +2484,16 @@ void Gource::draw(float t, float dt) {
     //debug info
 
     if(debug) {
-        font.setAlpha(1.0f);
+        font.setColour(vec4(1.0f));
 
         glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
         glEnable(GL_BLEND);
         glEnable(GL_TEXTURE_2D);
 
-
         font.print(1,20, "FPS: %.2f", fps);
         font.print(1,40,"Days Per Second: %.2f",
             gGourceSettings.days_per_second);
-        font.print(1,60,"Time Scale: %.2f", gGourceSettings.time_scale);
+        font.print(1,60,"Commit Queue: %d", commitqueue.size());
         font.print(1,80,"Users: %d", users.size());
         font.print(1,100,"Files: %d", files.size());
         font.print(1,120,"Dirs: %d",  gGourceDirMap.size());
