@@ -38,15 +38,7 @@
 
 #include "gource_settings.h"
 
-#include "git.h"
-#include "hg.h"
-#include "bzr.h"
-#include "gitraw.h"
-#include "cvs2cl.h"
-#include "cvs-exp.h"
-#include "custom.h"
-#include "apache.h"
-#include "svn.h"
+#include "logmill.h"
 
 #include "core/vbo.h"
 #include "bloom.h"
@@ -64,6 +56,9 @@ class Gource : public SDLApp {
 
     FrameExporter* frameExporter;
 
+    RLogMill* logmill;
+    bool shutdown;
+
     RCommitLog* commitlog;
     PositionSlider slider;
     ZoomCamera camera;
@@ -85,7 +80,7 @@ class Gource : public SDLApp {
     bool mouseclicked;
     bool mousedragged;
 
-    vec2f cursor_move;
+    vec2 cursor_move;
 
     bool recolour;
 
@@ -96,7 +91,7 @@ class Gource : public SDLApp {
 
     float rotate_angle;
 
-    vec2f mousepos;
+    vec2 mousepos;
 
     float last_percent;
 
@@ -143,7 +138,6 @@ class Gource : public SDLApp {
     FXFont font, fontlarge, fontmedium;
 
     bool first_read;
-    bool draw_loading;
     bool paused;
 
     float max_tick_rate;
@@ -183,6 +177,8 @@ class Gource : public SDLApp {
     Bounds2D user_bounds;
     Bounds2D active_user_bounds;
 
+    int commitqueue_max_size;
+
     std::deque<RCommit> commitqueue;
     std::map<std::string, RUser*> users;
     std::map<std::string, RFile*> files;
@@ -196,7 +192,7 @@ class Gource : public SDLApp {
     float message_timer;
 
     void setMessage(const char* str, ...);
-
+    
     void reset();
 
     RUser* addUser(const std::string& username);
@@ -212,6 +208,8 @@ class Gource : public SDLApp {
 
     void readLog();
 
+    void logReadingError(const std::string& error);
+
     void processCommit(RCommit& commit, float t);
     void addFileAction(const std::string& username, const std::string& action, RFile* file, float t);
 
@@ -219,8 +217,6 @@ class Gource : public SDLApp {
 
     void toggleCameraMode();
 
-    static RCommitLog* determineFormat(const std::string& logfile);
-
     void updateCamera(float dt);
 
     void updateUsers(float t, float dt);
@@ -244,11 +240,11 @@ class Gource : public SDLApp {
     void drawBackground(float dt);
 
     void drawScene(float dt);
-    
+
     void updateVBOs(float dt);
 
     void updateAndDrawEdges();
-    
+
     void drawFileShadows(float dt);
     void drawUserShadows(float dt);
     void drawActions(float dt);
@@ -271,14 +267,25 @@ public:
 
     void showSplash();
 
+    bool isBusy();
+
     void logic(float t, float dt);
     void draw(float t, float dt);
 
     void init();
+
+    void unload();
+    void reload();
+
+    void quit();
+    
     void update(float t, float dt);
     void keyPress(SDL_KeyboardEvent *e);
     void mouseMove(SDL_MouseMotionEvent *e);
     void mouseClick(SDL_MouseButtonEvent *e);
+#if SDL_VERSION_ATLEAST(1,3,0)
+    void mouseWheel(SDL_MouseWheelEvent *e);
+#endif
 };
 
 #endif
