@@ -51,7 +51,7 @@ void GourceSettings::help(bool extended_help) {
     printf("      --disable-auto-skip          Disable auto skip\n");
     printf("  -s, --seconds-per-day SECONDS    Speed in seconds per day (default: 10)\n");
     printf("      --realtime                   Realtime playback speed\n");
-    printf("  -c, --time-scale SCALE           Change simuation time scale (default: 1.0)\n");
+    printf("  -c, --time-scale SCALE           Change simulation time scale (default: 1.0)\n");
     printf("  -e, --elasticity FLOAT           Elasticity of nodes\n\n");
 
     printf("  --key                            Show file extension key\n\n");
@@ -93,8 +93,8 @@ if(extended_help) {
 
     printf("  --date-format FORMAT     Specify display date string (strftime format)\n\n");
 
-    printf("  --font-size SIZE         Font size\n");
-    printf("  --font-colour FFFFFF     Font colour in hex\n\n");
+    printf("  --font-size SIZE         Font size used by date and title\n");
+    printf("  --font-colour FFFFFF     Font colour used by date and title in hex\n\n");
 
     printf("  --file-extensions        Show filename extensions only\n\n");
 
@@ -113,15 +113,17 @@ if(extended_help) {
     printf("  --user-filter REGEX      Ignore usernames matching this regex\n");
     printf("  --file-filter REGEX      Ignore files matching this regex\n\n");
 
-    printf("  --user-friction SECONDS  Time users come to a complete hault (default: 0.67)\n");
+    printf("  --user-friction SECONDS  Change the rate users slow down (default: 0.67)\n");
     printf("  --user-scale SCALE       Change scale of users (default: 1.0)\n");
     printf("  --max-user-speed UNITS   Speed users can travel per second (default: 500)\n\n");
 
     printf("  --follow-user USER       Camera will automatically follow this user\n");
+    printf("  --highlight-dirs         Highlight the names of all directories\n");
     printf("  --highlight-user USER    Highlight the names of a particular user\n");
     printf("  --highlight-users        Highlight the names of all users\n\n");
-    printf("  --highlight-dirs         Highlight the names of all directories\n");
-    printf("  --highlight-colour       Font colour for highlighted text\n\n");
+    printf("  --highlight-colour       Font colour for highlighted users in hex.\n");
+    printf("  --selection-colour       Font colour for selected users and files.\n");
+    printf("  --dir-colour             Font colour for directories.\n\n");
 
     printf("  --hash-seed SEED         Change the seed of hash function\n\n");
 
@@ -137,8 +139,10 @@ if(extended_help) {
     }
 
 #ifdef _WIN32
-    printf("Press Enter\n");
-    getchar();
+    if(gSDLAppConsoleWindow) {
+        printf("Press Enter\n");
+        getchar();
+    }
 #endif
 
     exit(0);
@@ -182,6 +186,7 @@ GourceSettings::GourceSettings() {
     conf_sections["load-config"]     = "command-line";
     conf_sections["save-config"]     = "command-line";
     conf_sections["output-custom-log"] = "command-line";
+    conf_sections["log-level"]         = "command-line";
 
     //boolean args
     arg_types["help"]            = "bool";
@@ -239,6 +244,7 @@ GourceSettings::GourceSettings() {
     arg_types["follow-user"]    = "multi-value";
     arg_types["highlight-user"] = "multi-value";
 
+    arg_types["log-level"]          = "string";
     arg_types["background-image"]   = "string";
     arg_types["logo"]               = "string";
     arg_types["logo-offset"]        = "string";
@@ -265,6 +271,9 @@ GourceSettings::GourceSettings() {
     arg_types["title"]              = "string";
     arg_types["font-colour"]        = "string";
     arg_types["highlight-colour"]   = "string";
+    arg_types["selection-colour"]   = "string";
+    arg_types["dir-colour"]         = "string";
+    
 }
 
 void GourceSettings::setGourceDefaults() {
@@ -304,13 +313,17 @@ void GourceSettings::setGourceDefaults() {
     loop = false;
 
     logo = "";
-    logo_offset = vec2f(20.0f,20.0f);
+    logo_offset = vec2(20.0f,20.0f);
 
     colour_user_images = false;
     default_user_image = "";
     user_image_dir     = "";
     user_image_map.clear();
 
+    camera_zoom_min     = 50.0f;
+    camera_zoom_default = 100.0f;
+    camera_zoom_max     = 10000.0f;
+
     camera_mode     = "overview";
     padding         = 1.1f;
 
@@ -320,14 +333,16 @@ void GourceSettings::setGourceDefaults() {
     bloom_multiplier = 1.0f;
     bloom_intensity  = 0.75f;
 
-    background_colour = vec3f(0.1f, 0.1f, 0.1f);
+    background_colour = vec3(0.1f, 0.1f, 0.1f);
     background_image  = "";
 
     title             = "";
 
     font_size = 16;
-    font_colour = vec3f(1.0f, 1.0f, 1.0f);
-    highlight_colour = vec3f(1.0f, 1.0f, 0.3f);
+    dir_colour       = vec3(1.0f);
+    font_colour      = vec3(1.0f);
+    highlight_colour = vec3(1.0f);
+    selection_colour = vec3(1.0, 1.0, 0.3f);
 
     elasticity = 0.0f;
 
@@ -351,6 +366,8 @@ void GourceSettings::setGourceDefaults() {
 
     gStringHashSeed = 31;
 
+    log_level = LOG_LEVEL_ERROR;
+
     //delete file filters
     for(std::vector<Regex*>::iterator it = file_filters.begin(); it != file_filters.end(); it++) {
         delete (*it);
@@ -426,6 +443,19 @@ void GourceSettings::commandLineOption(const std::string& name, const std::strin
         return;
     }
 
+    if(name == "log-level") {
+        if(value == "warn") {
+            log_level = LOG_LEVEL_WARN;
+        } else if(value == "debug") {
+            log_level = LOG_LEVEL_DEBUG;
+        } else if(value == "info") {
+            log_level = LOG_LEVEL_INFO;
+        } else if(value == "error") {
+            log_level = LOG_LEVEL_ERROR;
+        }
+        return;
+    }
+
     std::string invalid_error = std::string("invalid ") + name + std::string(" value");
     throw ConfFileException(invalid_error, "", 0);
 }
@@ -718,7 +748,7 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         if(entry->isVec3()) {
             font_colour = entry->getVec3();
         } else if(colstring.size()==6 && sscanf(colstring.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
-            font_colour = vec3f(r,g,b);
+            font_colour = vec3(r,g,b);
             font_colour /= 255.0f;
         } else {
             conffile.invalidValueException(entry);
@@ -736,7 +766,7 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         if(entry->isVec3()) {
             background_colour = entry->getVec3();
         } else if(colstring.size()==6 && sscanf(colstring.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
-            background_colour = vec3f(r,g,b);
+            background_colour = vec3(r,g,b);
             background_colour /= 255.0f;
         } else {
             conffile.invalidValueException(entry);
@@ -754,12 +784,48 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         if(entry->isVec3()) {
             highlight_colour = entry->getVec3();
         } else if(colstring.size()==6 && sscanf(colstring.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
-            highlight_colour = vec3f(r,g,b);
+            highlight_colour = vec3(r,g,b);
             highlight_colour /= 255.0f;
         } else {
             conffile.invalidValueException(entry);
         }
     }
+    
+    if((entry = gource_settings->getEntry("selection-colour")) != 0) {
+
+        if(!entry->hasValue()) conffile.entryException(entry, "specify selection colour (FFFFFF)");
+
+        int r,g,b;
+
+        std::string colstring = entry->getString();
+
+        if(entry->isVec3()) {
+            selection_colour = entry->getVec3();
+        } else if(colstring.size()==6 && sscanf(colstring.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
+            selection_colour = vec3(r,g,b);
+            selection_colour /= 255.0f;
+        } else {
+            conffile.invalidValueException(entry);
+        }
+    }    
+    
+    if((entry = gource_settings->getEntry("dir-colour")) != 0) {
+
+        if(!entry->hasValue()) conffile.entryException(entry, "specify dir colour (FFFFFF)");
+
+        int r,g,b;
+
+        std::string colstring = entry->getString();
+
+        if(entry->isVec3()) {
+            dir_colour = entry->getVec3();
+        } else if(colstring.size()==6 && sscanf(colstring.c_str(), "%02x%02x%02x", &r, &g, &b) == 3) {
+            dir_colour = vec3(r,g,b);
+            dir_colour /= 255.0f;
+        } else {
+            conffile.invalidValueException(entry);
+        }
+    }
 
     if((entry = gource_settings->getEntry("background-image")) != 0) {
 
@@ -791,8 +857,8 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         int posx = 0;
         int posy = 0;
 
-        if(parseRectangle(logo_offset_str, &posx, &posy)) {
-            logo_offset = vec2f(posx, posy);
+        if(parseRectangle(logo_offset_str, posx, posy)) {
+            logo_offset = vec2(posx, posy);
         } else {
             conffile.invalidValueException(entry);
         }
@@ -1094,9 +1160,6 @@ void GourceSettings::importGourceSettings(ConfFile& conffile, ConfSection* gourc
         }
     }
 
-
-
-
     //validate path
     if(gource_settings->hasValue("path")) {
         path = gource_settings->getString("path");
