@@ -18,16 +18,16 @@
 #ifndef GOURCE_SETTINGS_H
 #define GOURCE_SETTINGS_H
 
-#define GOURCE_VERSION "0.37"
+#define GOURCE_VERSION "0.38"
 
 #include <dirent.h>
 
-#include "hg.h"
-#include "git.h"
-#include "bzr.h"
-#include "cvs-exp.h"
-#include "cvs2cl.h"
-#include "svn.h"
+#include "formats/hg.h"
+#include "formats/git.h"
+#include "formats/bzr.h"
+#include "formats/cvs-exp.h"
+#include "formats/cvs2cl.h"
+#include "formats/svn.h"
 
 #include "core/settings.h"
 #include "core/regex.h"
@@ -59,7 +59,7 @@ public:
     std::string path;
 
     std::string logo;
-    vec2f logo_offset;
+    vec2 logo_offset;
 
     float start_position;
     float stop_position;
@@ -82,6 +82,10 @@ public:
     std::string user_image_dir;
     std::map<std::string, std::string> user_image_map;
 
+    float camera_zoom_min;
+    float camera_zoom_max;
+    float camera_zoom_default;
+
     std::string camera_mode;
     float padding;
 
@@ -91,13 +95,13 @@ public:
     float bloom_multiplier;
     float bloom_intensity;
 
-    vec3f background_colour;
+    vec3 background_colour;
     std::string background_image;
 
     std::string title;
 
     int font_size;
-    vec3f font_colour;
+    vec3 font_colour;
 
     float elasticity;
 
@@ -117,8 +121,11 @@ public:
 
     bool highlight_dirs;
     bool highlight_all_users;
-    vec3f highlight_colour;
 
+    vec3 dir_colour;
+    vec3 highlight_colour;
+    vec3 selection_colour;
+    
     std::vector<std::string> highlight_users;
     std::vector<std::string> follow_users;
     std::vector<Regex*> file_filters;
@@ -129,6 +136,8 @@ public:
 
     TextureResource* file_graphic;
 
+    int log_level;
+
     GourceSettings();
 
     void setGourceDefaults();
