@@ -25,21 +25,26 @@ PositionSlider::PositionSlider(float percent) {
     font = fontmanager.grab("FreeSans.ttf", 16);
     font.dropShadow(true);
 
-    int gap = display.width / 30;
-
-    bounds.update(vec2f(gap, display.height - gap*2));
-    bounds.update(vec2f(display.width - gap, display.height - gap));
-
-    slidercol = vec3f(1.0, 1.0, 1.0);
+    slidercol = vec3(1.0, 1.0, 1.0);
 
     mouseover = -1.0;
 
     mouseover_elapsed = 1.0;
     fade_time = 1.0;
     alpha = 0.0;
+    
+    resize();
 }
 
-void PositionSlider::setColour(vec3f col) {
+void PositionSlider::resize() {
+    int gap = display.width / 30;
+
+    bounds.reset();
+    bounds.update(vec2(gap, display.height - gap*2));
+    bounds.update(vec2(display.width - gap, display.height - gap));
+}
+
+void PositionSlider::setColour(vec3 col) {
     slidercol = col;
 }
 
@@ -47,7 +52,7 @@ void PositionSlider::show() {
     mouseover_elapsed = 0.0;
 }
 
-bool PositionSlider::mouseOver(vec2f pos, float* percent_ptr) {
+bool PositionSlider::mouseOver(vec2 pos, float* percent_ptr) {
     if(bounds.contains(pos)) {
 
         mouseover_elapsed = 0;
@@ -65,7 +70,7 @@ bool PositionSlider::mouseOver(vec2f pos, float* percent_ptr) {
     return false;
 }
 
-bool PositionSlider::click(vec2f pos, float* percent_ptr) {
+bool PositionSlider::click(vec2 pos, float* percent_ptr) {
     if(mouseOver(pos, &percent)) {
 
         if(percent_ptr != 0) {
